@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2007 Pedro Castro
+ * Copyright (C) 2007-2008 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,11 +29,15 @@ public class Config {
 	private const string keyPrefix = "/apps/gnome-subtitles/";
 	private const string keyPrefs = keyPrefix + "preferences/";
 	private const string keyPrefsEncodings = keyPrefs + "encodings/";
+	private const string keyPrefsSpellCheck = keyPrefs + "spellcheck/";
 	private const string keyPrefsVideo = keyPrefs + "video/";
 	private const string keyPrefsWindow = keyPrefs + "window/";
 	
 	/* Constant key strings */
 	private const string keyPrefsEncodingsShownInMenu = keyPrefsEncodings + "shown_in_menu";
+	private const string keyPrefsSpellCheckActiveTextLanguage = keyPrefsSpellCheck + "active_text_language";
+	private const string keyPrefsSpellCheckActiveTranslationLanguage = keyPrefsSpellCheck + "active_translation_language";
+	private const string keyPrefsSpellCheckAutocheck = keyPrefsSpellCheck + "autocheck";
 	private const string keyPrefsVideoAutoChooseFile = keyPrefsVideo + "auto_choose_file";
 	private const string keyPrefsWindowHeight = keyPrefsWindow + "height";
 	private const string keyPrefsWindowWidth = keyPrefsWindow + "width";
@@ -52,6 +56,21 @@ public class Config {
 		set { SetStrings(keyPrefsEncodingsShownInMenu, value); }
 	}
 	
+	public string PrefsSpellCheckActiveTextLanguage {
+		get { return GetString(keyPrefsSpellCheckActiveTextLanguage, String.Empty); }
+		set { Set(keyPrefsSpellCheckActiveTextLanguage, value); }
+	}
+	
+	public string PrefsSpellCheckActiveTranslationLanguage {
+		get { return GetString(keyPrefsSpellCheckActiveTranslationLanguage, String.Empty); }
+		set { Set(keyPrefsSpellCheckActiveTranslationLanguage, value); }
+	}
+	
+	public bool PrefsSpellCheckAutocheck {
+		get { return GetBool(keyPrefsSpellCheckAutocheck, false); }
+		set { Set(keyPrefsSpellCheckAutocheck, value); }
+	}
+	
 	public bool PrefsVideoAutoChooseFile {
 		get { return GetBool(keyPrefsVideoAutoChooseFile, true); }
 		set { Set(keyPrefsVideoAutoChooseFile, value); }
@@ -69,6 +88,15 @@ public class Config {
 	
 	/* Private members */
 	
+	private string GetString (string key, string defaultValue) {
+		try {
+			return (string)client.Get(key);
+		}
+		catch (Exception) {
+			return defaultValue;
+		}
+	}
+	
 	private bool GetBool (string key, bool defaultValue) {
 		try {
 			return (bool)client.Get(key);
