@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2007 Pedro Castro
+ * Copyright (C) 2006-2008 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -160,6 +160,17 @@ public class EventHandlers {
 			Global.GUI.Video.Hide();
 	}
 	
+		
+	public void OnViewVideoSubtitlesText (object o, EventArgs args) {
+		if ((o as RadioMenuItem).Active)
+			Global.GUI.Video.Subtitle.ToShowText = true;
+	}
+	
+	public void OnViewVideoSubtitlesTranslation (object o, EventArgs args) {
+		if ((o as RadioMenuItem).Active)
+			Global.GUI.Video.Subtitle.ToShowText = false;
+	}
+	
 	/* Search Menu */
 	
 		
@@ -213,7 +224,7 @@ public class EventHandlers {
 	}
 	
 	public void OnVideoClose (object o, EventArgs args) {
-		Global.GUI.Video.Close();
+		Global.GUI.CloseVideo();
 	}
 
 	public void OnVideoPlayPause (object o, EventArgs args) {
@@ -255,6 +266,21 @@ public class EventHandlers {
 		}
 	}
 	
+	/* Tools Menu */
+		
+	public void OnToolsAutocheckSpelling (object o, EventArgs args) {
+		bool enabled = (o as CheckMenuItem).Active;
+		Global.SpellLanguages.Enabled = enabled;
+	}
+	
+	public void OnToolsSetTextLanguage (object o, EventArgs args) {
+		new SetLanguageDialog(SubtitleTextType.Text).Show();
+	}
+	
+	public void OnToolsSetTranslationLanguage (object o, EventArgs args) {
+		new SetLanguageDialog(SubtitleTextType.Translation).Show();
+	}
+	
 	
 	/*	Help Menu */
 	
