@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2007 Pedro Castro
+ * Copyright (C) 2006-2008 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@ public class Menus {
 	
 	public void BlankStartUp () {
 		SetBlankSensitivity();
+		SetBlankActivity();
 	}
 
 	public void UpdateFromNewDocument (bool wasLoaded) {
@@ -48,15 +49,19 @@ public class Menus {
 		SetSubtitleCountDependentSensitivity(Global.Document.Subtitles.Collection.Count);
 		SetFrameRateMenus();
 		SetActiveTimingMode(Global.TimingMode);
+		
+		SetToolsAutocheckSpellingSensitivity(true);
+		SetCheckMenuItemActivity(WidgetNames.ToolsAutocheckSpelling, Global.SpellLanguages.Enabled);
 	}
 	
 	public void UpdateFromNewTranslationDocument () {
-		SetNewTranslationSensitivity(true);
+		SetTranslationSensitivity(true);
 		UpdateUndoRedoMessages();
 	}
 	
 	public void UpdateFromCloseTranslation () {
-    	SetNewTranslationSensitivity(false);
+    	SetTranslationSensitivity(false);
+    	SetViewVideoSubtitlesActivity(true);
     	UpdateUndoRedoMessages();
     }
 	
@@ -102,6 +107,16 @@ public class Menus {
     public void UpdateFromCommandActivated () {
     	UpdateUndoRedoMessages();
     }
+    
+    public void UpdateFromOpenVideo () {
+    	SetVideoSensitivity(true);
+    	SetViewVideoSubtitlesSensitivity();
+    }
+    
+    public void UpdateFromCloseVideo () {
+    	SetVideoSensitivity(false);
+    	SetViewVideoSubtitlesSensitivity(false, false);
+    }
 
 	public void SetActiveTimingMode (TimingMode mode) {
 		if (mode == TimingMode.Times)
@@ -137,21 +152,12 @@ public class Menus {
 		SetSensitivity(WidgetNames.SearchFindPrevious, true);
 	}
 	
-	public void SetViewVideoActivity (bool activity) {
-		SetCheckMenuItemActivity(WidgetNames.ViewVideo, activity);
+	public void SetToolsAutocheckSpellingSensitivity (bool sensitivity) {
+		SetSensitivity(WidgetNames.ToolsAutocheckSpelling, sensitivity);
 	}
 	
-	public void SetVideoSensitivity (bool sensitivity) {
-		SetSensitivity(WidgetNames.VideoClose, sensitivity);
-		SetSensitivity(WidgetNames.VideoPlayPause, sensitivity);
-		SetSensitivity(WidgetNames.VideoRewind, sensitivity);
-		SetSensitivity(WidgetNames.VideoForward, sensitivity);
-		
-		/* Set video menu dependent sensitivity if there is 1 selected subtitle. */
-		if ((Global.GUI.View.Selection.Count == 1) && sensitivity)
-			SetVideoSelectionDependentSensitivity(true);
-		else
-			SetVideoSelectionDependentSensitivity(false);
+	public void SetViewVideoActivity (bool activity) {
+		SetCheckMenuItemActivity(WidgetNames.ViewVideo, activity);
 	}
 	
 	public void AddFrameRateVideoTag (float frameRate) {
@@ -247,6 +253,8 @@ public class Menus {
 		SetSensitivity(WidgetNames.SearchFindNext, false);
 		SetSensitivity(WidgetNames.SearchFindPrevious, false);
 		SetSensitivity(WidgetNames.SearchReplace, false);
+		/* Tools Menu */
+		SetToolsAutocheckSpellingSensitivity(false);
 		/* Toolbar */
 		SetSensitivity(WidgetNames.SaveButton, false);
 		SetSensitivity(WidgetNames.UndoButton, false);
@@ -261,6 +269,10 @@ public class Menus {
 		SetSensitivity(WidgetNames.UnderlineButton, false);
 	}
 	
+	private void SetBlankActivity () {
+		SetCheckMenuItemActivity(WidgetNames.ToolsAutocheckSpelling, Global.SpellLanguages.Enabled);
+	}
+	
 	private void SetNewDocumentSensitivity (bool wasLoaded) {
 		if (!wasLoaded) {	
 			/* File Menu */
@@ -276,9 +288,14 @@ public class Menus {
 			/* View Menu */
 			SetSensitivity(WidgetNames.ViewTimes, true);
 			SetSensitivity(WidgetNames.ViewFrames, true);
+			SetViewVideoSubtitlesSensitivity();
 			/* Search Menu */
 			SetSensitivity(WidgetNames.SearchFind, true);
 			SetSensitivity(WidgetNames.SearchReplace, true);
+			/* Tools Menu */
+			SetSensitivity(WidgetNames.ToolsSetTextLanguage, true);
+			SetSensitivity(WidgetNames.ToolsSetTranslationLanguage, false);
+			
 			/* Toolbar */
 			SetSensitivity(WidgetNames.SaveButton, true);
 			SetSensitivity(WidgetNames.FindButton, true);
@@ -297,9 +314,14 @@ public class Menus {
 			SetSensitivity(WidgetNames.EditCut, false);
 			SetSensitivity(WidgetNames.EditCopy, false);
 			SetSensitivity(WidgetNames.EditPaste, false);
+			/* View Menu */
+			SetViewVideoSubtitlesSensitivity();
 			/* Search Menu */
 			SetSensitivity(WidgetNames.SearchFindNext, false);
 			SetSensitivity(WidgetNames.SearchFindPrevious, false);
+			/* Tools Menu */
+			SetSensitivity(WidgetNames.ToolsSetTranslationLanguage, false);
+			
 			/* Toolbar */
 			SetSensitivity(WidgetNames.UndoButton, false);
 			SetSensitivity(WidgetNames.RedoButton, false);
@@ -309,10 +331,12 @@ public class Menus {
 		}	
 	}
 	
-	private void SetNewTranslationSensitivity (bool sensitivity) {
+	private void SetTranslationSensitivity (bool sensitivity) {
 		SetSensitivity(WidgetNames.FileTranslationSave, sensitivity);
 		SetSensitivity(WidgetNames.FileTranslationSaveAs, sensitivity);
 		SetSensitivity(WidgetNames.FileTranslationClose, sensitivity);
+		SetSensitivity(WidgetNames.ToolsSetTranslationLanguage, sensitivity);
+		SetViewVideoSubtitlesSensitivity();
 	}
 	
 	private void SetFrameRateMenus () {
@@ -338,6 +362,27 @@ public class Menus {
 		SetToggleToolButtonActivity(WidgetNames.UnderlineButton, underline, Global.Handlers.OnEditFormatUnderline);
 	}
 	
+		
+	private void SetViewVideoSubtitlesActivity (bool isTextActive) {
+		if (isTextActive)
+			SetCheckMenuItemActivity(WidgetNames.ViewVideoSubtitlesText, true);
+		else
+			SetCheckMenuItemActivity(WidgetNames.ViewVideoSubtitlesTranslation, true);
+	}
+	
+	private void SetVideoSensitivity (bool sensitivity) {
+		SetSensitivity(WidgetNames.VideoClose, sensitivity);
+		SetSensitivity(WidgetNames.VideoPlayPause, sensitivity);
+		SetSensitivity(WidgetNames.VideoRewind, sensitivity);
+		SetSensitivity(WidgetNames.VideoForward, sensitivity);
+		
+		/* Set video menu dependent sensitivity if there is 1 selected subtitle. */
+		if ((Global.GUI.View.Selection.Count == 1) && sensitivity)
+			SetVideoSelectionDependentSensitivity(true);
+		else
+			SetVideoSelectionDependentSensitivity(false);
+	}
+	
 	private void SetStylesSensitivity (bool sensitivity) {
 		if (Global.GetWidget(WidgetNames.EditFormatBold).Sensitive != sensitivity) {
 			SetSensitivity(WidgetNames.EditFormatBold, sensitivity);
@@ -365,6 +410,18 @@ public class Menus {
 		}
 	}
 	
+	private void SetViewVideoSubtitlesSensitivity () {
+		bool isVideoLoaded = Global.GUI.Video.IsLoaded;
+		bool textSensitivity = isVideoLoaded && Global.IsDocumentLoaded;
+		bool translationSensitivity = isVideoLoaded && textSensitivity && Global.Document.IsTranslationLoaded;
+		SetViewVideoSubtitlesSensitivity(textSensitivity, translationSensitivity);	
+	}
+	
+	private void SetViewVideoSubtitlesSensitivity (bool textSensitivity, bool translationSensitivity) {
+		SetSensitivity(WidgetNames.ViewVideoSubtitlesText, textSensitivity);
+		SetSensitivity(WidgetNames.ViewVideoSubtitlesTranslation, translationSensitivity);
+	}
+	
 	private void SetCheckMenuItemActivity (string menuItemName, bool isActive) {
 		(Global.GetWidget(menuItemName) as CheckMenuItem).Active = isActive;
 	}
