@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2007 Pedro Castro
+ * Copyright (C) 2006-2008 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,6 +77,10 @@ public class Video {
 		get { return position; }
 	}
 	
+	public VideoSubtitle Subtitle {
+		get { return subtitle; }
+	}
+	
 	public bool IsLoaded {
 		get { return isLoaded; }
 	}
@@ -127,7 +131,6 @@ public class Video {
 		SilentDisablePlayPauseButton();		
 		SetControlsSensitivity(false);
 
-		Global.GUI.Menus.SetVideoSensitivity(false);
 		Global.GUI.Menus.RemoveFrameRateVideoTag(oldFrameRate);
 	}
 
